"""
MaaMCP - MCP server based on MaaFramework

Provides Android and Windows desktop automation capabilities for AI assistants.
"""

try:
    from maa_mcp._version import __version__
except ImportError:
    __version__ = "0.0.0.dev0"

__author__ = "MaaXYZ"
__email__ = "mistereo@hotmail.com"
